# Purchase Order Preview

**Order Number**: {order_number}
**Supplier ID**: {supplier_id}
**Location ID**: {location_id}
**Status**: {status}

## Summary

- **Total Cost**: ${total_cost:,.2f}
- **Currency**: {currency}
- **Entity Type**: {entity_type}

## Preview Mode

This is a **preview only**. No order has been created.

To create this purchase order, call again with `confirm=true`.

## Next Steps

{next_actions_text}

______________________________________________________________________

**Status**: Preview - awaiting confirmation
